==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/modulelistandkeyaugment/rev20160826/modulelistandkeyaugment/val/DefaultAugmentedSchVal.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.modulelistandkeyaugment.rev20160826.modulelistandkeyaugment.val;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.modulelistandkey.rev20160826.modulelistandkey.Bitdef;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedSchVal.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedSchVal extends InnerModelObject implements AugmentedSchVal {
    protected List<Bitdef> ll;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public List<Bitdef> ll() {
        return ll;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void ll(List<Bitdef> ll) {
        valueLeafFlags.set(LeafIdentifier.LL.getLeafIndex());
        this.ll = ll;
    }

    @Override
    public void addToLl(Bitdef addTo) {
        if (ll == null) {
            ll = new ArrayList<>();
        }
        ll.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(ll, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedSchVal) {
            DefaultAugmentedSchVal other = (DefaultAugmentedSchVal) obj;
            return
                Objects.equals(ll, other.ll) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ll=" + ll)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedSchVal.
     */
    public DefaultAugmentedSchVal() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/modulelistandkeyaugment/rev20160826/modulelistandkeyaugment/val/DefaultAugmentedSchVal.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.modulelistandkeyaugment.rev20160826.modulelistandkeyaugment.val;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.modulelistandkey.rev20160826.modulelistandkey.Bitdef;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedSchVal.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedSchVal extends InnerModelObject implements AugmentedSchVal {
    protected List<Bitdef> ll;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public List<Bitdef> ll() {
        return ll;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void ll(List<Bitdef> ll) {
        valueLeafFlags.set(LeafIdentifier.LL.getLeafIndex());
        this.ll = ll;
    }

    @Override
    public void addToLl(Bitdef addTo) {
        if (ll == null) {
            ll = new ArrayList<>();
        }
        ll.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(ll, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedSchVal) {
            DefaultAugmentedSchVal other = (DefaultAugmentedSchVal) obj;
            return
                Objects.deepEquals(ll, other.ll) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ll=" + ll)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedSchVal.
     */
    public DefaultAugmentedSchVal() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
